==> core-react-0.8.0.tgz: package/es/Nav/Nav.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import Button from '../Button';
import Scrollbar from '../Scrollbar';
import { MenuIcon } from './MenuIcon';
import NavBottom from './NavBottom';

var Nav = /*#__PURE__*/function (_Component) {
  _inherits(Nav, _Component);

  function Nav(props) {
    var _this;

    _classCallCheck(this, Nav);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Nav).call(this, props));
    _this.state = {
      selectedId: props.selectedId || '',
      collapsed: _this.props.collapsed,
      collapsedTrigger: ''
    };
    return _this;
  }

  _createClass(Nav, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        nav: this
      };
    }
  }, {
    key: "handleItemClick",
    value: function handleItemClick(props, e) {
      this.setState({
        selectedId: props.id
      });
      this.props.onItemClick && this.props.onItemClick(props, e);
    }
  }, {
    key: "handleCollapseToggle",
    value: function handleCollapseToggle(collapsed) {
      this.setState({
        collapsed: collapsed,
        collapsedTrigger: collapsed ? 'close-icon' : 'menu-icon'
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var collapsed = this.state.collapsed;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          width = _this$props.width,
          logoUrl = _this$props.logoUrl,
          user = _this$props.user,
          onSettingClick = _this$props.onSettingClick,
          onLogoutClick = _this$props.onLogoutClick,
          other = _objectWithoutProperties(_this$props, ["children", "className", "width", "logoUrl", "user", "onSettingClick", "onLogoutClick"]);

      delete other.selectedId;
      delete other.onItemClick;
      delete other.user;
      delete other.collapsed;

      if (width) {
        if (collapsed) {
          var _other$style;

          other === null || other === void 0 ? true : (_other$style = other.style) === null || _other$style === void 0 ? true : delete _other$style.width;
        } else {
          other.style = Object.assign(other.style || {}, {
            width: width
          });
        }
      }

      return React.createElement("div", _extends({
        className: cx("".concat("waui", "-nav"), _defineProperty({}, "".concat("waui", "-nav--collapsed"), collapsed), className)
      }, other), React.createElement("div", {
        className: "".concat("waui", "-nav__top")
      }, React.createElement("div", {
        className: "".concat("waui", "-nav__top-left-container"),
        onClick: function onClick() {
          return _this2.handleCollapseToggle(false);
        }
      }, React.createElement(MenuIcon, {
        className: "".concat("waui", "-nav__top-left-container-menu-icon")
      })), React.createElement("div", {
        className: "".concat("waui", "-nav__top-center-container")
      }, React.createElement("img", {
        className: "".concat("waui", "-nav__top-center-container-logo"),
        src: logoUrl,
        alt: "Logo"
      })), React.createElement("div", {
        className: "".concat("waui", "-nav__top-right-container")
      }, React.createElement(Button, {
        className: cx("".concat("waui", "-nav__btn-icon"), "".concat("waui", "-nav__top-right-container-close-icon")),
        onClick: function onClick() {
          return _this2.handleCollapseToggle(true);
        },
        icon: "close"
      }))), React.createElement(Scrollbar, {
        className: "".concat("waui", "-nav__scrollbar")
      }, React.createElement("ul", null, children)), React.createElement(NavBottom, {
        user: user,
        onSettingClick: onSettingClick,
        onLogoutClick: onLogoutClick
      }));
    }
  }]);

  return Nav;
}(Component);

Nav.childContextTypes = {
  nav: PropTypes.instanceOf(Nav)
};
Nav.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** The id of active nav item */
  selectedId: PropTypes.string.isRequired,

  /** The url of logo image such as svg, png */
  logoUrl: PropTypes.string,

  /** Whether the navigation is collapsed */
  collapsed: PropTypes.bool,

  /** The width of expanded navigation, default value is `330px` */
  width: PropTypes.number,

  /** User information */
  user: PropTypes.shape({
    avatar: PropTypes.string,
    name: PropTypes.string,
    company: PropTypes.string
  }),

  /** The click event of each NavItem, the parameters are the current NavItem props and event object */
  onItemClick: PropTypes.func,

  /** The click event of setting button */
  onSettingClick: PropTypes.func,

  /** The click event of logout button */
  onLogoutClick: PropTypes.func
};
Nav.defaultProps = {
  collapsed: true
};
export default Nav;

==> core-react-0.8.2.tgz: package/es/Nav/Nav.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import Button from '../Button';
import Scrollbar from '../Scrollbar';
import { MenuIcon } from './MenuIcon';
import NavBottom from './NavBottom';

var Nav = /*#__PURE__*/function (_Component) {
  _inherits(Nav, _Component);

  function Nav(props) {
    var _this;

    _classCallCheck(this, Nav);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Nav).call(this, props));
    _this.state = {
      selectedId: props.selectedId || '',
      collapsed: _this.props.collapsed,
      collapsedTrigger: ''
    };
    return _this;
  }

  _createClass(Nav, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        nav: this
      };
    }
  }, {
    key: "handleItemClick",
    value: function handleItemClick(props, e) {
      this.setState({
        selectedId: props.id
      });
      this.props.collapsed && this.handleCollapseToggle(true);
      this.props.onItemClick && this.props.onItemClick(props, e);
    }
  }, {
    key: "handleCollapseToggle",
    value: function handleCollapseToggle(collapsed) {
      this.setState({
        collapsed: collapsed,
        collapsedTrigger: collapsed ? 'close-icon' : 'menu-icon'
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var collapsed = this.state.collapsed;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          width = _this$props.width,
          logoUrl = _this$props.logoUrl,
          user = _this$props.user,
          onSettingClick = _this$props.onSettingClick,
          onLogoutClick = _this$props.onLogoutClick,
          other = _objectWithoutProperties(_this$props, ["children", "className", "width", "logoUrl", "user", "onSettingClick", "onLogoutClick"]);

      delete other.selectedId;
      delete other.onItemClick;
      delete other.user;
      delete other.collapsed;

      if (width) {
        if (collapsed) {
          var _other$style;

          other === null || other === void 0 ? true : (_other$style = other.style) === null || _other$style === void 0 ? true : delete _other$style.width;
        } else {
          other.style = Object.assign(other.style || {}, {
            width: width
          });
        }
      }

      return (/*#__PURE__*/React.createElement("div", _extends({
          className: cx("".concat("waui", "-nav"), _defineProperty({}, "".concat("waui", "-nav--collapsed"), collapsed), className)
        }, other), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-nav__top")
        }, /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-nav__top-left-container"),
          onClick: function onClick() {
            return _this2.handleCollapseToggle(false);
          }
        }, /*#__PURE__*/React.createElement(MenuIcon, {
          className: "".concat("waui", "-nav__top-left-container-menu-icon")
        })), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-nav__top-center-container")
        }, /*#__PURE__*/React.createElement("img", {
          className: "".concat("waui", "-nav__top-center-container-logo"),
          src: logoUrl,
          alt: "Logo"
        })), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-nav__top-right-container")
        }, /*#__PURE__*/React.createElement(Button, {
          className: cx("".concat("waui", "-nav__btn-icon"), "".concat("waui", "-nav__top-right-container-close-icon")),
          onClick: function onClick() {
            return _this2.handleCollapseToggle(true);
          },
          icon: "close"
        }))), /*#__PURE__*/React.createElement(Scrollbar, {
          className: "".concat("waui", "-nav__scrollbar")
        }, /*#__PURE__*/React.createElement("ul", null, children)), /*#__PURE__*/React.createElement(NavBottom, {
          user: user,
          onSettingClick: onSettingClick,
          onLogoutClick: onLogoutClick
        }))
      );
    }
  }]);

  return Nav;
}(Component);

Nav.childContextTypes = {
  nav: PropTypes.instanceOf(Nav)
};
Nav.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** The id of active nav item */
  selectedId: PropTypes.string.isRequired,

  /** The url of logo image such as svg, png */
  logoUrl: PropTypes.string,

  /** Whether the navigation is collapsed */
  collapsed: PropTypes.bool,

  /** The width of expanded navigation, default value is `330px` */
  width: PropTypes.number,

  /** User information */
  user: PropTypes.shape({
    avatar: PropTypes.string,
    name: PropTypes.string,
    company: PropTypes.string
  }),

  /** The click event of each NavItem, the parameters are the current NavItem props and event object */
  onItemClick: PropTypes.func,

  /** The click event of setting button */
  onSettingClick: PropTypes.func,

  /** The click event of logout button */
  onLogoutClick: PropTypes.func
};
Nav.defaultProps = {
  collapsed: true
};
export default Nav;
